/*
 *  translate.c
 *  FileTesto
 *
 *  Created by Stefano Guerrini on 12/03/07.
 *
 */

#include <stdio.h>
#include <string.h>
#include "definizioni.h"

#define BUF_LEN		256

/*
 * Sostituisce i caratteri contenuti in un insieme con i corrispondenti
 * caratteri di un altro insieme.
 * IN:  fin    - file di input
 *      fout   - file di otput
 *      setin  - insieme dei caratteri da sostitiure (rappresentato come stringa)
 *      setout - caratteri da inserire
 *      setin e setout devono avere la stessa lunghezza.
 *      l'i-esimo carattere di setout rimpiazza l'i-esimo carattere di setin
 * OUT: FT_OK == 0 se la sostituzione puo' essere completata senza problemi,
 *      codice di errore altrimenti
 */
int translate(FILE *fin, FILE *fout, const char *setin, const char *setout){
	char buffer[BUF_LEN], *p;
	const char *qin, *qout;
	
	// leggo il file di input una linea per volta
	// memorizzando la linea letta nel buffer  
	while (fgets(buffer, BUF_LEN, fin) != NULL) {
		 // scorro i carratteri della linea contenuta nel buffer
		for (p = buffer; *p != '\0'; p++) {
			// verifico se devo rimpiazzare il carattere corrente
			if ((qin = strchr(setin, *p)) != NULL) {
				// devo sostituire il carattere corrente
				// determino la posizione in setout della traduzione
				qout = setout+(qin-setin);
				// sostituisco
				*p = *qout;
			}
		}
		// scrivo la linea tradotta
		if (fputs(buffer, fout) == EOF) {
			int ret = errore(FT_ERR_WRITE, "translate", "Impossibile scrivere sul file di output");
			return ret;
		}
	}
	
	return FT_OK;
}
